@@ -38,7 +38,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     let real_input = include_str!("day05_input.txt");
     test_part_one!(real_input => 374_269);
     test_part_two!(real_input => 27_720_699);
