@@ -44,7 +44,7 @@ pub fn solve(input: &mut Input) -> Result<Frequency, String> {
 
 #[test]
 pub fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("+1\n-2\n+3\n+1" => 3);
     test_part_one!("+1\n+1\n+1" => 3);
